#
# spec file for package perl-Devel-PPPort
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Devel-PPPort
Name:           perl-Devel-PPPort
Version:        3.68
Release:        1.15
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl/Pollution/Portability
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AT/ATOOMIC/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Perl's API has changed over time, gaining new features, new functions,
increasing its flexibility, and reducing the impact on the C namespace
environment (reduced pollution). The header file written by this module,
typically _ppport.h_, attempts to bring some of the newer Perl API features
to older versions of Perl, so that you can worry less about keeping track
of old releases, but users can still reap the benefit.

'Devel::PPPort' contains two functions, 'WriteFile' and 'GetFileContents'.
'WriteFile''s only purpose is to write the _ppport.h_ C header file. This
file contains a series of macros and, if explicitly requested, functions
that allow XS modules to be built using older versions of Perl. Currently,
Perl versions from 5.003 to 5.20 are supported.

'GetFileContents' can be used to retrieve the file contents rather than
writing it out.

This module is used by 'h2xs' to write the file _ppport.h_.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes HACKERS README soak TODO

%changelog
* Sat Mar 19 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.68
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.68 - 2022-03-18
  * fix newSVsv_flags: rename variable to fix C++ compilation issue
  * Update dNOOP definition for Perl < 5.27.7
* Wed Mar  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.67
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
* Thu Mar  3 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.66
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.66 - 2022-03-22
  * Fix corrupted release (missing files)
  3.65 - 2022-03-02
  * Enable AppVeyor CI
  * Fix CROAK_IF_ERROR without BRACE GROUPS
  * Refactor to use static inline function in multiple parts/inc
  * devel/regenerate: Add --skip-devels option
  * Don't list has_builtin as being provided
* Wed Feb  2 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.64
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.64 - 2022-02-01
  * Fix: better support for STMT_START / STMT_END definition
  * Fix: Only use '-Wdeclaration-after-statement' if possible
  * 5.55.2 functions: av_fetch_simple, av_store_simple, voidnonfinal
  * 5.33 functions: pack_cat, pad_compname_type
  * apicheck.pl: multiple improvements & code refactor for regenerating files
* Wed Jul  7 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.63
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.63 - 2021-07-06
  * Backport SvPVCLEAR
  * Backport ASSUME
  * Backport NOT_REACHED
  * Backport G_LIST
  * various internal changes
* Sat Oct 17 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.62
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.62 - 2020-10-16
  * Restore missing PPPort.pm
  * Fix metaCPAN indexing
* Tue Oct 13 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.61
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
* Wed Aug 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.60
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.60 - 2020-08-11
  * Restore PERL_BCDVERSION helper which is used on CPAN
  * A few API elements were not properly found, like IVTYPE
  3.59 - 2020-08-10
  * Add PERL_VERSION_* compare macros
  * Rename PERL_BCDVERSION to internal name to discourage future use
  * Stop versioning generated test files
  * Enforce strict & warnings
  * Avoid indirect calls
  * scanprov: multiple improvements
  * Use ivers() in tests
  * Update POD documentation and HACKERS file
  * Change ppport.h --api-info to not output non-API info unless that is the
    only match
  * Find more elements to be listed in the --api-info option (and similar) to
    ppport.h
* Tue Mar 10 2020 <timueller+perl@suse.de>
- updated to 3.58
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.58 - 2020-03-09
  * Safer definition of UVCHR_SKIP
  * Make sure WIDEST_UTYPE is unsigned
  * Avoid Pax Header in tarballs
* Sat Feb  1 2020 <timueller+perl@suse.de>
- updated to 3.57
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.57 - 2020-01-31
  * Fix eval_sv for Perl versions prior to 5.6.0 (Pali)
  * Fix t/ppphtest.t for Perl versions prior to 5.6.0 (Pali)
  * Fix compilation of sv_setsv_flags when GCC extensions are not present (Pali)
  * Fix SV_NOSTEAL on 5.7.2 (Karl Williamson)
  * Fix multiple unit test issues (Craig A. Berry, Karl Williamson, Pali)
  * Avoid generating warnings on early Perls (Karl Williamson)
  * Backport memCHRs (Karl Williamson)
  * Implement sv_setsv_flags() with SV_NOSTEAL and SV_GMAGIC flags for Perl versions < 5.7.3 (Pali)
  * Implement UTF8f format and its UTF8fARG macro (Pali)
* Tue Nov 26 2019 <timueller+perl@suse.de>
- updated to 3.56
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.56 - 2019-11-25
  * mktests.PL: use FindBin for INC setup
  * devel/regenerate: Adjust POD line length
  * Fix compilation with Visual C++ bugs introduced in 3.55 (Tomasz Konojacki)
  * Fix mess.t failures when on VC++ when $0 contains backslashes (Tomasz Konojacki)
  * Fix failing builds on 5.20.[1-3] introduced in 3.55 (Karl Williamson)
  * Change tests to accept and use Test::More-like functions (Karl Williamson)
* Fri Nov  8 2019 <timueller+perl@suse.de>
- updated to 3.55
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.55 - 2019-11-07
  * Fix p5-Text-Xslate on Perl 5.8.5 (Nicolas R)
  * Fix EBCDIC build problem (Karl Williamson)
  * Fix isGRAPH_L1() bug (Karl Williamson)
  * utf8_to_uvchr_buf: Fix error checking on early EBCDICs and proper length (Karl Williamson)
  * HACKERS: fix typos and clarification (Karl Williamson)
  * Update bugtracker and repository URLs (Nicolas R)  (upstream/urls)
  * Add warning about UTF-8 unreliable in early perls (Karl Williamson)
  * Add withinCOUNT and inRANGE (Karl Williamson)
  * Implement G_RETHROW for eval_sv (Pali)
  * Backport some isFOO_LC macros (Karl Williamson)
  * Backport isFOO_LC_utf8_safe() (Karl Williamson)
  * Backport toFOO_uvchr() (Karl Williamson)
  * Backport isFOO_uvchr() (Karl Williamson)
  * Backport isFOO_utf8_safe() macros (Karl Williamson)
  * Backport toLOWER_utf8_safe and kin (Karl Williamson)
  * Backport UTF8_MAXBYTES_CASE (Karl Williamson)
  * Backport UTF8_CHK_SKIP (Karl Williamson)
  * Backport UTF8_SKIP (Karl Williamson)
  * Backport UNI to/from NATIVE (Karl Williamson)
* Sat Sep 28 2019 <timueller+perl@suse.de>
- updated to 3.54
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.54 - 2019-09-27
  * Fix Unix-format path in Devel::PPPort's Makefile.PL
  * Fix utf8_to_uvchr_buf for 5.7.0
  * Add hint for utf8_to_uvchr()
  * Fix hints for is_ascii_string
  * Use numeric comparisons with $]
  * Fix 'for loops' to work on early perls
  * Can't use GCC brace groups before 5.4
  * Add script to regenerate ppport.fnc
  * Suppress useless warning
  * Fix mktests.PL for Perl 5.8.0
  * Implement sv_len_utf8_nomg() and sv_len_utf8()
  * Fix eval_pv for Perl versions prior to 5.31.2
  * Consolidate UTF-8 functions/macros into new file
  * Implement sv_mortalcopy_flags()
  * Implement newSVsv_flags()
  * Enable Perl compile-time warnings at all place
  * Improve Makefile.PL
  * Add tests for IVdf, UVuf, IV_MAX and UV_MAX
  3.53 - 2019-09-27
  * Rename PPPort_xs.PL to RealPPPort_xs.PL
  * Fix compilation issues with version older than 5.010
  * Fix compilation issues with version older than 5.010
* Wed May 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.52
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.52 - 2019-05-14
  * fix utf8_to_uvchr_buf retval in 5.30
* Wed May  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.51
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  Revision history for Devel-PPPort
  3.51 - 2019-05-01
  * include the module version in metadata for proper PAUSE indexing
  3.50 - 2019-04-30
  * Order warn before uv for packWARN (shown in 5.6.1)
  3.49 - 2019-04-29
  * Fix tests for 64bit int, 32bit ptr platforms
  3.48 - 2019-04-28
  * Order misc before uv for UNLIKELY (<=5.8.8)
  3.47 - 2019-04-27
  * re-fix leaky code (used only in tests)
  3.46 - 2019-04-26
  * Fix the isFOO character type classification macros to work properly on
    all versions, as follows:
  * Fixed isALNUM, isALPHA, isDIGIT, isIDFIRST, isLOWER, and isUPPER on
    very early perls to not be locale-dependent
  * Fixed isASCII on early perls to work with signed char arguments
  * Fixed isCNTRL on early perls to know that DEL is a control
  * Fixed isSPACE on perls before 5.20 to know that VERTICAL TAB is a
    space
  * Added isALPHANUMERIC, synonym for isALNUMC
  * Added isIDCONT, to match legal non-initial characters in an
    identifier
  * Added isOCTAL, to match [0-7]
  * Added isWORDCHAR, synonym for isALNUM
  * Make all the character classification isFOO macros work on EBCDIC
    platforms on all versions
  * Added isFOO_A synonyms for all character classification isFOO
    macros
  * Provide LIKELY/UNLIKELY branch prediction
  * Provide av_tindex/av_top_index
  * Provide __ASSERT_ for assertions inside macros
  * Provide UTF8_SAFE_SKIP
  * Provide my_strnlen()
  * Provide utf8_to_uvchr_buf()
  * Replace utf8_to_uvchr() with a safer version
  * Provide UNICODE_REPLACEMENT
* Sat Mar 30 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.45
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.45 - 2019-03-19
  * Restore missing unit tests from the previous release.
* Thu Feb 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.44
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
* Sat Sep 22 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.43
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
* Sun Apr 22 2018 coolo@suse.com
- updated to 3.42
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.42 - 2018-04-21
  * Include 'Changes' (this file) in the distribution.
  3.41 - 2018-04-21
  * Fix security problem: CWE-134: Use of Externally-Controlled Format String.
  * Fix WIDEST_UTYPE.
  * Add the following functions:
    croak_sv, die_sv, mess_sv, warn_sv, mess, vmess, warn_nocontext,
    croak_nocontext, croak_no_modify, croak_memory_wrap, croak_xs_usage.
  * Delist functions listed as deprecated or unstable.
  * (perl #132876) define API macros on if the NEED_ macro is defined.
  * (perl #132876) only define croak_xs_usage()'s assert macro if cxu requested.
  * (perl #132761) updates for older perls.
  * Do not define PERL_MAGIC_qr more times.
  * Do not mask Perl_warn_nocontext and Perl_croak_nocontext.
    (Fixes compile errors on older threaded Perl versions.)
  * Skip ASCII tests on non-ASCII platforms.
  * Skip tests invalid on EBCDIC.
  * Will now compile under C++11.
  * Documentation improvements.
* Tue May 16 2017 coolo@suse.com
- updated to 3.36
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.36 - 2017-05-14
  * Support Perl 5.26.* which no longer has '.' in @INC
* Fri Jun 24 2016 coolo@suse.com
- updated to 3.35
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.35 - 2016-06-17
  * Fix compilation in bleadperl by removing a bad test.
* Mon Jun 13 2016 coolo@suse.com
- updated to 3.34
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.34 - 2016-06-04
  * Fix compilation on Windows with certain compilers.
    (__attribute__ not recognized. (#GH 36)
* Sun Jun 12 2016 coolo@suse.com
- updated to 3.33
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.33 - 2016-06-03
  * Add PERL_OP_PARENT related macros, and cBOOL
  * Add SvRXOK/SvRX/PERL_MAGIC_qr
    (Thanks to arc)
  * sort files from all_files_in_dir (GH #28, https://bugs.debian.org/801523
    (Thanks to ntyni)
  * Fix coverity finding in test (GH #25)
    (Thanks to jhi)
  * Add PERL_UNUSED_RESULT and a test (GH #20)
  * Don't redefine MUTABLE_PTR if it's already there (GH #23)
  * Add C_ARRAY_LENGTH and C_ARRAY_END (GH #16)
  * Fix gv_fetchpvn_flags and add init_gv_pvn (#GH 32)
    (Thanks to leont)
  * Fix compiler warnings
    (Thanks to Dave M.)
* Fri Oct  2 2015 coolo@suse.com
- updated to 3.32
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.32 - 2015-09-30
  * Lexical topic no longer works as of perl 5.23
* Mon Apr 13 2015 coolo@suse.com
- updated to 3.31
  see /usr/share/doc/packages/perl-Devel-PPPort/Changes
  3.31 - 2015-03-12
  * Regen todo files to sync with blead
  3.30 - 2015-03-05
  * Update typemap to account for STRLEN added in
    3.29, which prevented compiling on older Perls
  3.29 - 2015-03-05
  * Fix issue found by Coverity
    (Thanks to Dave M. for patch)
  3.28 - 2015-01-16
  * Update MANIFEST for regened base/todo files
  3.27 - 2015-01-13
  * Regen base and todo files.
  * Fix isASCII and isCNTRL for <5.6.0
  * Other minor fixups.
    (Thanks to mhx for all of the work on this release)
  3.26 - 2015-01-07
  * Silence some warnings on compilation in perl core
    (Thanks to Dave M. for patches)
  3.25 - 2014-12-02
  * Add caller_cx (works back to Perl 5.6.0)
    (Thanks to Ben Morrow for patch)
  * Silence compiler and coverity warnings
    (Thanks to jhi for patches)
  3.24 - 2014-05-08
  * Remove SvREFCNT_dec_NN until it can be implemented
    properly.
    (Thanks to bulk88 for reporting GH #10)
  * Fix GH #11 - compiler warning under clang
    (Thanks to jhi for reporting it)
  * Fix GH #12 - compiler warnings
    (Thanks to jhi for reporting it)
  3.23 - 2014-04-12
  * Add support for HeUTF8
  * Add GetFileContents() to retrieve the contents of the
    ppport.h file
  * Update MAX_VER to be 5.20
  * Update issue tracker to GitHub
  3.22 - 2014-03-19
  * Add support for the following API
    SvREFCNT_dec_NN
    mg_findext
    sv_unmagicext
  * Update META
    Move bug tracker to github
    Provide link to repository
  * Avoid syntax disallowed by C++11
    (Thanks to Tony C for the patch)
  3.21 - 2013-08-17
  * Fix cpan #87870: Merge core perl commit 90b0dc0e2e
    (Thanks to Father Chrysostomos for the original patch and
    to Steve Hay for forwarding it)
  * Fix cpan #86975: Deterministically order API elements in POD
    (Thanks to Karl Williamson for providing a patch.)
  * Fix cpan #81796: my $_ is deprecated
    (Thanks to Nicholas Clark for providing a patch)
  * Fix cpan #81484: fix isASCII and isCNTRL for inputs > 255
    (Thanks to Karl Williamson for providing a patch)
  * Fix cpan #80314: make use of PERL_NO_GET_CONTEXT the default
  * Fix cpan #79814: Install to 'site' for perl 5.11+
    (Thanks to Robert Sedlacek for providing a patch)
  * Fix cpan #78271: Need SvPV_nomg_nolen
  * Adapt buildperl.pl for newer Perl releases
  * Update masked_versions regex for 5.005 thread builds
  * Some tweaks needed to support 5.003 on 64-bit platforms
* Fri Nov 18 2011 coolo@suse.com
- update to 3.20
  * fix CPAN #56749: isASCII and isCNTRL macros are buggy
    (thanks to Karl Williamson for providing a patch and patiently
    waiting almost two years for me to integrate it)
  * fix CPAN #70427: RealPPPort.xs:1587: error: lvalue required as unary ‘&’ operand
  * keep up with latest core changes
  * fix a warning emitted by the test suite with older perls
  * added support for the following API
    newSVpvs_share
    get_cvn_flags
    get_cvs
  * fix CPAN #50763: mistaken use of $[
    (thanks to Zefram for spotting this)
  * remove spurious PUSHMARK from Perl_ppaddr_t
    (thanks to Gerard Goossen for providing a patch)
  * improved support for newer compilers in buildperl.pl
    (thanks to Philippe Bruhat (BooK) for providing a patch)
  * added support for the following API
    memEQs
    memNEs
  * lots of small toolchain updates
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 3.19
